@@ -1,5 +1,6 @@
 require "objspace"
 require "tempfile"
+require "bigdecimal"
 
 module TestUnitTestUtil
   private
@@ -23,7 +24,11 @@ module TestUnitTestUtil
     result = Test::Unit::TestResult.new
     test = test_case.new(name)
     yield(test) if block_given?
-    test.run(result) {}
+    suite = Test::Unit::TestSuite.new(test_case.name, test_case)
+    suite << test
+    runner_class.run_all_tests do |run_context|
+      suite.run(result, run_context: run_context) {}
+    end
     result
   end
 
